Usage
latex.fdt(x,
columns=1:6,
round=2,
format.classes=TRUE,
pattern='%.2f',
replace.breaks=TRUE,
where='!tbp',
caption=NULL,
label=NULL,
size='',
algtable=c('\\flushleft', '\\centering', '\\flushright'),
hline1='\\hline',
header=NULL,
hline2='\\hline',
algclim='l',
algfreq='r',
hline3='\\hline')Arguments
columns
A vector of integers to select colums of the
data.frame table. For example: columns=c(1:2, 4, 6).
round
Rounds the fractionary columns of the fdt to the specified number of decimal places.
The default is 2.
format.classes
Logical, if TRUE, the default, the first column of the
data.frame table will be formated using regular expression according with pattern argument.
pattern
Same as fmt in sprintf.
The default is '%.2f'. replace.breaks
Logical, if TRUE, the default, the mathematical symbols for breaks: [,) or (,],
will be replaced by the LaTeX $$ or $$ symbols.
- where
{Specifies the l