| plot.fdt | R Documentation |
S3 methods for fdt.default and fdt.multiple objects.
It is possible to plot histograms and polygons (absolute, relative
and cumulative).
## S3 methods
## S3 method for class 'fdt.default'
plot(x,
type=c('fh', 'fp',
'rfh', 'rfp',
'rfph', 'rfpp',
'd',
'cdh', 'cdp',
'cfh', 'cfp',
'cfph', 'cfpp'),
v=FALSE,
v.round=2,
v.pos=3,
xlab="Class limits",
xlas=0,
ylab=NULL,
col="gray",
xlim=NULL,
ylim=NULL,
main=NULL,
x.round=2, ...)
## S3 method for class 'fdt.multiple'
plot(x,
type=c('fh', 'fp',
'rfh', 'rfp',
'rfph', 'rfpp',
'd',
'cdh', 'cdp',
'cfh', 'cfp',
'cfph', 'cfpp'),
v=FALSE,
v.round=2,
v.pos=3,
xlab="Class limits",
xlas=0,
ylab=NULL,
col="gray",
xlim=NULL,
ylim=NULL,
main=NULL,
main.vars=TRUE,
x.round=2,
grouped=FALSE,
args.legend=NULL, ...)
## S3 method for class 'fdt_cat.default'
plot(x,
type=c('fb', 'fp', 'fd',
'rfb', 'rfp', 'rfd',
'rfpb', 'rfpp', 'rfpd',
'cfb', 'cfp', 'cfd',
'cfpb', 'cfpp', 'cfpd',
'pa'),
v=FALSE,
v.round=2,
v.pos=3,
xlab=NULL,
xlas=0,
ylab=NULL,
y2lab=NULL,
y2cfp=seq(0, 100, 25),
col=gray(.4),
xlim=NULL,
ylim=NULL,
main=NULL,
box=FALSE, ...)
## S3 method for class 'fdt_cat.multiple'
plot(x,
type=c('fb', 'fp', 'fd',
'rfb', 'rfp', 'rfd',
'rfpb', 'rfpp', 'rfpd',
'cfb', 'cfp', 'cfd',
'cfpb', 'cfpp', 'cfpd',
'pa'),
v=FALSE,
v.round=2,
v.pos=3,
xlab=NULL,
xlas=0,
ylab=NULL,
y2lab=NULL,
y2cfp=seq(0, 100, 25),
col=gray(.4),
xlim=NULL,
ylim=NULL,
main=NULL,
main.vars=TRUE,
box=FALSE, ...)
x |
A ‘fdt’ object. |
type |
the type of the plot: ‘rfb:’ relative frequency barplot, ‘rfpb:’ relative frequency (%) barplot, ‘d:’ density, ‘cfb:’ cumulative frequency barplot, ‘cdpb:’ cumulative frequency (%) barplot, ‘pa:’ pareto chart. |
v |
logical flag: should the values be added to the plot? |
v.round |
if |
v.pos |
if |
xlab |
a label for the ‘x’ axis. |
xlas |
an integer which controls the orientation of the ‘x’ axis labels: |
ylab |
a label for the ‘y’ axis. |
y2lab |
a label for the ‘y2’ axis. |
y2cfp |
a cumulative percent frequency for the ‘y2’ axis. The default is |
col |
a |
xlim |
the ‘x’ limits of the plot. |
ylim |
the ‘y’ limits of the plot. |
main |
title of the plot(s). This option has priority over ‘main.vars’, i.e., if any value is provided,
the variable names will not be used as title of the plot(s). For |
main.vars |
logical flag: should the variables names be added as title of each plot (default |
x.round |
a numeric value to round the ‘x’ ticks:
‘0:’ parallel to the axes, |
box |
if |
grouped |
if |
args.legend |
list of additional arguments to be passed to |
... |
optional plotting parameters. |
The result is a single histogram or polygon (absolute, relative or cumulative)
for fdt.default or a set of histograms or polygons (absolute, relative or
cumulative) for fdt.multiple objects.
Both ‘default and multiple’ try to compute the maximum number of histograms
that will fit on one page, then it draws a matrix of histograms. More than one
graphical device may be opened to show all histograms.
The result is a single bar plot, polygon, dot chart (absolute, relative or cumulative)
and Pareto chart for fdt_cat.default or a set of the same graphs for
fdt_cat.multiple objects.
Both ‘default and multiple’ try to compute the maximum number of histograms
that will fit on one page, then it draws a matrix of graphs listed above. More than one
graphical device may be opened to show all graphs.
Faria, J. C.
Allaman, I. B
Jelihovschi, E. G.
library(fdth)
#===============================
# Vectors: univariate numerical
#===============================
x <- rnorm(n=1e3,
mean=5,
sd=1)
(ft <- fdt(x))
# Histograms
plot(ft) # Absolute frequency histogram
plot(ft,
main='My title')
plot(ft,
x.round=3,
col='darkgreen')
plot(ft,
xlas=2)
plot(ft,
x.round=3,
xlas=2,
xlab=NULL)
plot(ft,
v=TRUE,
cex=.8,
x.round=3,
xlas=2,
xlab=NULL,
col=rainbow(11))
plot(ft,
type='fh') # Absolute frequency histogram
plot(ft,
type='rfh') # Relative frequency histogram
plot(ft,
type='rfph') # Relative frequency (%) histogram
plot(ft,
type='cdh') # Cumulative density histogram
plot(ft,
type='cfh') # Cumulative frequency histogram
plot(ft,
type='cfph') # Cumulative frequency (%) histogram
# Polygons
plot(ft,
type='fp') # Absolute frequency polygon
plot(ft,
type='rfp') # Relative frequency polygon
plot(ft,
type='rfpp') # Relative frequency (%) polygon
plot(ft,
type='cdp') # Cumulative density polygon
plot(ft,
type='cfp') # Cumulative frequency polygon
plot(ft,
type='cfpp') # Cumulative frequency (%) polygon
# Density
plot(ft,
type='d') # Density
# Theoretical curve and fdt
x <- rnorm(1e5,
mean=5,
sd=1)
plot(fdt(x,
k=100),
type='d',
col=heat.colors(100))
curve(dnorm(x,
mean=5,
sd=1),
col='darkgreen',
add=TRUE,
lwd=3)
#=================================
# Vectors: univariate categorical
#=================================
x <- sample(letters[1:5],
1e3,
rep=TRUE)
(ft.c <- fdt_cat(x))
# Barplot: the default
plot(ft.c)
# Barplot
plot(ft.c,
type='fb')
# Polygon
plot(ft.c,
type='fp')
# Dotchart
plot(ft.c,
type='fd')
# Pareto chart
plot(ft.c,
type='pa')
#======================================================
# Data.frames: multivariate with categorical variables
#======================================================
mdf <- data.frame(X1=rep(LETTERS[1:4], 25),
X2=as.factor(rep(1:10, 10)),
Y1=c(NA, NA, rnorm(96, 10, 1), NA, NA),
Y2=rnorm(100, 60, 4),
Y3=rnorm(100, 50, 4),
Y4=rnorm(100, 40, 4),
stringsAsFactors=TRUE)
str(mdf)
# Histograms
(ft <- fdt(mdf,
na.rm=TRUE))
plot(ft,
v=TRUE,
cex=.8)
plot(ft,
col='darkgreen',
ylim=c(0, 40))
plot(ft,
col=rainbow(8),
ylim=c(0, 40),
main=LETTERS[1:4])
plot(ft,
type='fh')
plot(ft,
type='rfh')
plot(ft,
type='rfph')
plot(ft,
type='cdh')
plot(ft,
type='cfh')
plot(ft,
type='cfph')
# Polygons
plot(ft,
v=TRUE,
type='fp')
plot(ft,
type='rfp')
plot(ft,
type='rfpp')
plot(ft,
type='cdp')
plot(ft,
type='cfp')
plot(ft,
type='cfpp')
# Density
plot(ft,
type='d')
levels(mdf$X1)
plot(fdt(mdf,
k=5,
by='X1',
na.rm=TRUE),
ylim=c(0, 12))
levels(mdf$X2)
plot(fdt(mdf,
breaks='FD',
by='X2',
na.rm=TRUE))
plot(fdt(mdf,
k=5,
by='X2',
na.rm=TRUE)) # It is difficult to compare
plot(fdt(mdf,
k=5,
by='X2',
na.rm=TRUE),
ylim=c(0, 8)) # Easy
plot(fdt(iris,
k=5))
plot(fdt(iris,
k=5),
col=rainbow(5))
plot(fdt(iris,
k=5,
by='Species'),
v=TRUE)
ft <- fdt(iris,
k=10)
plot(ft)
plot(ft,
type='d')
# Categorical data
(ft.c <- fdt_cat(mdf))
plot(ft.c)
plot(ft.c,
type='fd',
pch=19)
#========================
# Matrices: multivariate
#========================
plot(fdt(state.x77))
plot(fdt(volcano))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.